/*==================================================================*/
/* CS6490 Graphics Support Code					    */
/* Header File							    */
/* Version 2.0                                                      */
/*==================================================================*/

#ifndef GTGFXSUPPORT
#define GTGFXSUPPORT

#include <stdio.h>

/*------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#endif

/*==================================================================*/
/* gtImage Data Type Definition                                     */
/*------------------------------------------------------------------*/

typedef struct {
   /* an image structure holds the image size */
   /* and a dynamic array of pixels */
   int w, h;
   int *values;
} gtImage;

void gtImageInit ( gtImage *I );
void gtImageDestroy ( gtImage *I );

void gtImageGetSize ( gtImage *I, int *w, int *h );
void gtImageSetSize ( gtImage *I, int w, int h );

FILE* gtImageWritePPM ( gtImage *I, char *filename );

void gtImageWritePixel ( gtImage *I, int w, int h, int r, int g, int b, float opacity );
void gtImageReadPixel ( gtImage *I, int w, int h, int *r, int *g, int *b );

/*==================================================================*/
/* A Single Window Interface                                        */
/*------------------------------------------------------------------*/

enum GTWriteMode { GT_OVERWRITE, GT_REPLACE, GT_XOR };
enum GTColor { GT_RED, GT_GREEN, GT_BLUE };
enum GTEnable { GT_DEPTH_TEST };

void gtBeginGraphics ( int w, int h );
void gtEndGraphics ();
void gtWriteFramebuffer ( char *filename );
void gtClear ( int r, int g, int b );
void gtWritePixel ( int x, int y, int r, int g, int b, float opacity);
void gtSetWriteMode ( int /* GTWriteMode */ mode );
void gtWaitOnEscape ();
void gtGetFramebufferSize ( int *w, int *h );

/*==================================================================*/
/* Declarations of polygon drawing routines                         */
/*------------------------------------------------------------------*/

enum GTDrawable { GT_NONE, GT_POLYGON ,GT_LINES };

void gtColor3f ( float r, float g, float b );
void gtVertex2f ( float x, float y );
void gtBegin ( int /* GTDrawable */ );
void gtEnd ();

/*------------------------------------------------------------------*/

#ifdef __cplusplus
}
#endif

/*------------------------------------------------------------------*/

#endif

